==> dl.php?src=linea21_1_8.zip: linea21/languages/es/lang_project.utf-8.php <==
<?php
/**
 * @package linea21\languages\es
 * @author $Author$ - Marta Rada Arias, Alejandro Villar Fernández (www.icane.es) & linea21 <info@linea21.com>
 * @version $Id$ 
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */



$lang['project']['section'] = "proyectos";

/*	nommage des modules
 *  	*/
$lang['project']['name']="proyecto";
$lang['project']['confirm_add'] = "Proyecto agregado correctamente";
$lang['project']['confirm_mod'] = "Proyecto actualizado correctamente";
$lang['project']['confirm_sup'] = "Proyecto eliminado correctamente";


/*	nommage rubrique module
 *  	*/
$lang['project']['add']= "Añadir nuevo ".$lang['project']['name'];
$lang['project']['mod']= "Editar ".$lang['project']['name'];
$lang['project']['sup']= "Eliminar ".$lang['project']['name'];
$lang['project']['det']= ucfirst($lang['project']['name']). " detalles";
$lang['project']['list']= "Ver proyectos";



/*	nommage rubrique add / mod /det
 *  	*/
$lang['project']['add_title']='Añadir valores al nuevo '.$lang['project']['name'];

/*	nommage élément rubrique
 *  	*/
$lang['project']['name']="nombre";
$lang['project']['goal']="goal(s)"; // @todo translation
$lang['project']['description']="descripción";
$lang['project']['body']="cuerpo";
$lang['project']['budget']="budget (in €)"; // @todo translation
$lang['project']['budget_comment']="budget - complement"; // @todo translation
$lang['project']['elected']="elected referent(s)"; // @todo translation
$lang['project']['manager']="manager(s)"; // @todo translation
$lang['project']['coordinator']="coordinator"; // @todo translation
$lang['project']['team']="team project"; // @todo translation
$lang['project']['partners']="partners"; // @todo translation
$lang['project']['begin_date']="fecha de comienzo";
$lang['project']['estimated_date']="fecha de finalización estimada ";
$lang['project']['end_date']="fecha de finalización efectiva ";
$lang['project']['progression']="progression (%)"; // @todo translation
$lang['project']['parent']="proyecto superior";
$lang['project']['sub-projects']="sub-proyectos";
$lang['project']['priority']="prioridad";
$lang['project']['theme']='área ';
$lang['project']['workshop']="grupo de trabajo";
$lang['project']['comment']="comment"; // @todo translation
$lang['project']['sdi']="indicadores";
$lang['project']['scale']="escala";
$lang['project']['author']="autor";
$lang['project']['statut']='estado';

$lang['project']['steering_title']='Sterring / animation'; // @todo translation
$lang['project']['calendar_title']='Calendar'; // @todo translation
$lang['project']['budget_title']='Budget'; // @todo translation

/*	nommage quickbox
 *  	*/
$lang['project']['qb_titleadd']=" proyectos agregados recientemente";
$lang['project']['qb_titlemod']=" proyectos modificados recientemente";
$lang['project']['qb_titlesup']=" proyectos eliminados recientemente";
$lang['project']['qb_titlepubli']=' últimas publicaciones';

/*	divers
 *  	*/
$lang['project']['select_choice']="-- Seleccione de la lista --";

$lang['project']['nb_total']='proyecto(s) en la base de datos.';
$lang['project']['statut_filter']='Mostrar por estados';
$lang['project']['all']='Mostrar lista';
$lang['project']['noresult']='No existen proyectos con este criterio ';

/*	messages
 *  	*/
$lang['project']['no_name']='El nombre es requerido';
$lang['project']['no_description']='La descripción es requerida';
$lang['project']['no_body']='El cuerpo es requerido';
$lang['project']['no_scale']='La escala es requerida';
$lang['project']['no_priority']='La prioridad es requerida';
$lang['project']['progression_error']='Progression indicator muste take a value between 0 and 100.'; // @todo translation
$lang['project']['incorrect_user']='Given manager \'%s\' is unknown from the application'; // @todo translation
$lang['project']['incorrect_userperm']='Given manager  \'%s\' has not required permissions'; // @todo translation
$lang['project']['budget_integer']='Budget : an integer value is required'; // @todo translation
$lang['project']['begin_date_err']= $lang['project']['begin_date']. ' : ';
$lang['project']['estimated_date_err']=$lang['project']['estimated_date']. ' : ';
$lang['project']['end_date_err']=$lang['project']['end_date']. ' : ';

/*	rubrique d'aide
 *  	*/
$lang['project']['help_add1']="Para añadir un nuevo proyecto, inserte la información requerida en el formulario.";
$lang['project']['help_add2']='Completado el cuestionario, revise los valores en el resumen.';
$lang['project']['help_add3']='Validado el resumen, haga click en "revisar valores" si desea realizar cambios.';

$lang['project']['help_list1']='Para mas información haga click sobre el nombre del proyecto.';
$lang['project']['help_list2']="Para eliminar un proyecto, haga click en el icono 'eliminar proyecto.'";
$lang['project']['help_list3']="Para editar un proyecto, haga click en el icono 'editar proyecto'.";
$lang['project']['help_list4']='Para añadir un nuevo proyecto, haga click en "añadir nuevo proyecto".';
$lang['project']['help_list5']="Si desea realizar búsquedas dentro del módulo 'proyectos', haga click en 'buscar'.";

$lang['project']['help_mod1']='Para editar un proyecto, inserte la información requerida en el formulario.';
$lang['project']['help_mod2']='Completado el formulario, revise los valores en el resumen.';
$lang['project']['help_mod3']='Validado el resumen, haga click en "revisar valores" si desea realizar cambios.';

$lang['project']['help_det1']="Para acceder al proyecto superior, haga click sobre su nombre.";
$lang['project']['help_det2']="Para eliminar un proyecto, haga click en el icono 'eliminar proyecto'.";
$lang['project']['help_det3']="Para editar un proyecto, haga click en el icono 'editar proyecto'.";

$lang['project']['help_sup1']="Atención, si el actual proyecto contiene sub-proyectos, estos no serán automáticamente eliminados.";
?>

==> dl.php?src=linea21_2_0_0.zip: linea21/languages/es/lang_project.utf-8.php <==
<?php
/**
 * @package linea21\languages\es
 * @author $Author$ - Marta Rada Arias, Alejandro Villar Fernández (www.icane.es) & linea21 <info@linea21.com>
 * @version $Id$ 
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */



$lang['project']['section'] = "proyectos";

/*	nommage des modules
 *  	*/
$lang['project']['name']="proyecto";
$lang['project']['confirm_add'] = "Proyecto agregado correctamente";
$lang['project']['confirm_mod'] = "Proyecto actualizado correctamente";
$lang['project']['confirm_sup'] = "Proyecto eliminado correctamente";


/*	nommage rubrique module
 *  	*/
$lang['project']['add']= "Añadir nuevo ".$lang['project']['name'];
$lang['project']['mod']= "Editar ".$lang['project']['name'];
$lang['project']['sup']= "Eliminar ".$lang['project']['name'];
$lang['project']['det']= ucfirst($lang['project']['name']). " detalles";
$lang['project']['list']= "Ver proyectos";



/*	nommage rubrique add / mod /det
 *  	*/
$lang['project']['add_title']='Añadir valores al nuevo '.$lang['project']['name'];

/*	nommage élément rubrique
 *  	*/
$lang['project']['name']="nombre";
$lang['project']['goal']="goal(s)"; // @todo translation
$lang['project']['description']="descripción";
$lang['project']['body']="cuerpo";
$lang['project']['budget']="budget (in €)"; // @todo translation
$lang['project']['budget_comment']="budget - complement"; // @todo translation
$lang['project']['elected']="elected referent(s)"; // @todo translation
$lang['project']['manager']="manager(s)"; // @todo translation
$lang['project']['coordinator']="coordinator"; // @todo translation
$lang['project']['team']="team project"; // @todo translation
$lang['project']['partners']="partners"; // @todo translation
$lang['project']['begin_date']="fecha de comienzo";
$lang['project']['estimated_date']="fecha de finalización estimada ";
$lang['project']['end_date']="fecha de finalización efectiva ";
$lang['project']['progression']="progression (%)"; // @todo translation
$lang['project']['parent']="proyecto superior";
$lang['project']['sub-projects']="sub-proyectos";
$lang['project']['priority']="prioridad";
$lang['project']['level']='nivel';
$lang['project']['workshop']="grupo de trabajo";
$lang['project']['comment']="comment"; // @todo translation
$lang['project']['sdi']="indicadores";
$lang['project']['scale']="escala";
$lang['project']['author']="autor";
$lang['project']['statut']='estado';
$lang['project']['add_indicator']="add an indicator"; // @todo translation
$lang['project']['add_indicator_value']="enter an indicator value"; // @todo translation
$lang['project']['completion']="completion"; // @todo translation
$lang['project']['report']="Export / generate report"; // @todo translation
$lang['project']['steering_title']='Sterring / animation'; // @todo translation
$lang['project']['calendar_title']='Calendar'; // @todo translation
$lang['project']['budget_title']='Budget'; // @todo translation
$lang['project']['finalities']='Finalities'; // @todo translation

// views
$lang['project']['level_view']='Ordered by levels'; // @todo translation
$lang['project']['flat_view']='Flat view'; // @todo translation
$lang['project']['finality_view']='Ordered by finality'; // @todo translation

/*	nommage quickbox
 *  	*/
$lang['project']['qb_titleadd']=" proyectos agregados recientemente";
$lang['project']['qb_titlemod']=" proyectos modificados recientemente";
$lang['project']['qb_titlesup']=" proyectos eliminados recientemente";
$lang['project']['qb_titlepubli']=' últimas publicaciones';

/*	divers
 *  	*/
$lang['project']['select_choice']="-- Seleccione de la lista --";

$lang['project']['nb_total']='proyecto(s) en la base de datos.';
$lang['project']['statut_filter']='Mostrar por estados';
$lang['project']['all']='Mostrar lista';
$lang['project']['noresult']='No existen proyectos con este criterio ';
$lang['project']['session-stored']="%s projects are stored in session"; // @todo translation

/*	messages
 *  	*/
$lang['project']['no_name']='El nombre es requerido';
$lang['project']['no_description']='La descripción es requerida';
$lang['project']['no_body']='El cuerpo es requerido';
$lang['project']['no_scale']='La escala es requerida';
$lang['project']['no_level']='El nivel es requerido';
$lang['project']['no_priority']='La prioridad es requerida';
$lang['project']['progression_error']='Progression indicator muste take a value between 0 and 100.'; // @todo translation
$lang['project']['incorrect_user']='Given manager \'%s\' is unknown from the application'; // @todo translation
$lang['project']['incorrect_userperm']='Given manager  \'%s\' has not required permissions'; // @todo translation
$lang['project']['budget_integer']='Budget : an integer value is required'; // @todo translation
$lang['project']['begin_date_err']= $lang['project']['begin_date']. ' : ';
$lang['project']['estimated_date_err']=$lang['project']['estimated_date']. ' : ';
$lang['project']['end_date_err']=$lang['project']['end_date']. ' : ';
$lang['project']['inconsistent_date']='Given dates seem to be inconsistent. Please, change them.'; // @todo translation

/*	rubrique d'aide
 *  	*/
$lang['project']['help_add1']="Para añadir un nuevo proyecto, inserte la información requerida en el formulario.";
$lang['project']['help_add2']='Completado el cuestionario, revise los valores en el resumen.';
$lang['project']['help_add3']='Validado el resumen, haga click en "revisar valores" si desea realizar cambios.';

$lang['project']['help_list1']='Para mas información haga click sobre el nombre del proyecto.';
$lang['project']['help_list2']="Para eliminar un proyecto, haga click en el icono 'eliminar proyecto.'";
$lang['project']['help_list3']="Para editar un proyecto, haga click en el icono 'editar proyecto'.";
$lang['project']['help_list4']='Para añadir un nuevo proyecto, haga click en "añadir nuevo proyecto".';
$lang['project']['help_list5']="Si desea realizar búsquedas dentro del módulo 'proyectos', haga click en 'buscar'.";

$lang['project']['help_mod1']='Para editar un proyecto, inserte la información requerida en el formulario.';
$lang['project']['help_mod2']='Completado el formulario, revise los valores en el resumen.';
$lang['project']['help_mod3']='Validado el resumen, haga click en "revisar valores" si desea realizar cambios.';

$lang['project']['help_det1']="Para acceder al proyecto superior, haga click sobre su nombre.";
$lang['project']['help_det2']="Para eliminar un proyecto, haga click en el icono 'eliminar proyecto'.";
$lang['project']['help_det3']="Para editar un proyecto, haga click en el icono 'editar proyecto'.";

$lang['project']['help_sup1']="Atención, si el actual proyecto contiene sub-proyectos, estos no serán automáticamente eliminados.";
?>
